#include <iostream>
#include <string>

#include <facesdk/FaceSDK.h>

const std::string IDLIVEFACE_HOME = "/opt/idliveface";

void ProcessLivenessResult(const facesdk::PipelineResult& result) {
    std::cout << "Result: " << result << std::endl;

    if (result.quality_result.score < 0.5) {
        std::cout << "Image has a bad quality" << std::endl;
    } else if (result.liveness_result.probability >= 0.5) {
        std::cout << "Image is genuine" << std::endl;
    } else {
        std::cout << "Image is spoofed" << std::endl;
    }
}

int main() {
    try {
        std::cout << "Initializing..." << std::endl;
        facesdk::InitConfigPtr config =
                facesdk::InitConfig::createConfig(IDLIVEFACE_HOME + "/data/pipelines/astraea.json");
        facesdk::PipelinePtr pipeline = facesdk::FaceSDK::getPipeline("ConfigurablePipeline", config);

        std::cout << "\nChecking liveness for real_face.jpg" << std::endl;
        facesdk::ImagePtr image = facesdk::Image::createImage(IDLIVEFACE_HOME + "/examples/images/real_face.jpg");
        facesdk::PipelineResult result = pipeline->checkLiveness(image);
        ProcessLivenessResult(result);

        std::cout << "\nChecking liveness for spoof_face.jpg" << std::endl;
        image = facesdk::Image::createImage(IDLIVEFACE_HOME + "/examples/images/spoof_face.jpg");
        result = pipeline->checkLiveness(image);
        ProcessLivenessResult(result);

        std::cout << "\nChecking liveness for face_not_found.jpg" << std::endl;
        image = facesdk::Image::createImage(IDLIVEFACE_HOME + "/examples/images/face_not_found.jpg");
        pipeline->checkLiveness(image);

    } catch (const facesdk::FaceException& e) {
        std::cout << "Error: " << e.what() << ", status: " << e.status() << std::endl;
    }

    return 0;
}
